@@ -22,14 +22,15 @@ have as part of the public API, please let us know.
 import os
 import sys
 
-valid_version = sys.version_info.major >= 3 and sys.version_info.minor >= 6
+valid_version = sys.version_info >= (3, 6, 1)
 
 if not valid_version:  # pragma: no cover
-    print("Python 3.6 or newer is required.")
+    # Rich does not support 3.6.0
+    print("Python 3.6.1 or newer is required.")
     sys.exit()
 
 del valid_version
-__version__ = "0.5.0"
+__version__ = "0.5.18"
 
 
 # ===========================================
@@ -37,6 +38,9 @@ __version__ = "0.5.0"
 import inspect
 from pathlib import Path
 
+from .my_gettext import current_lang
+from friendly import rich_formatters, theme, settings
+
 from friendly_traceback import (
     editors_helpers,
     exclude_directory_from_traceback,
@@ -58,9 +62,6 @@ from friendly_traceback import (  # noqa
     set_include,
 )
 
-from .my_gettext import current_lang
-from friendly import rich_formatters, theme, settings
-
 
 exclude_directory_from_traceback(os.path.dirname(__file__))
 get_lang = current_lang.get_lang
@@ -206,7 +207,7 @@ def set_formatter(
     if formatter is not None:
         settings.write(option="formatter", value=formatter)
         if background is not None:
-            settings.write(option="background", value=background)
+            background = theme.colours.set_background_color(background)
         else:
             old_background = settings.read(option="background")
             if (
@@ -215,18 +216,18 @@ def set_formatter(
             ):
                 background = old_background
     elif background is not None:
-        settings.write(option="background", value=background)
+        background = theme.colours.set_background_color(background)
         old_formatter = settings.read(option="formatter")
-        if old_formatter is not None:
-            formatter = old_formatter
-            old_color_system = settings.read(option="color_system")
-            if old_color_system is not None:
-                color_system = old_color_system
-            old_force_jupyter = settings.read(option="force_jupyter")
-            if old_force_jupyter is not None:
-                force_jupyter = old_force_jupyter
-        else:
+        if old_formatter is None:
             return
+        formatter = old_formatter
+        old_color_system = settings.read(option="color_system")
+        if old_color_system is not None:
+            color_system = old_color_system
+        old_force_jupyter = settings.read(option="force_jupyter")
+        if old_force_jupyter is not None:
+            force_jupyter = old_force_jupyter
+
     if color_system is not None:
         settings.write(option="color_system", value=color_system)
     if force_jupyter is not None:
@@ -236,7 +237,8 @@ def set_formatter(
     session.use_rich = True
     session.jupyter_button_style = ""
     set_stream()
-    settings.write(option="formatter", value=formatter)
+    if isinstance(formatter, str):
+        settings.write(option="formatter", value=formatter)
     if formatter in ["dark", "light"]:
         session.console = theme.init_rich_console(
             style=formatter,
@@ -254,7 +256,7 @@ def set_formatter(
             background=background,
         )
         formatter = rich_formatters.jupyter_interactive
-        session.jupyter_button_style = ";color: white; background-color:black;"
+        session.jupyter_button_style = ";color:white; background-color:#101010;"
     elif formatter in ["interactive", "interactive-light"]:
         session.console = theme.init_rich_console(
             style="light",
